@@ -4,7 +4,15 @@ the :class:`layout.pages.output.PagesLM` class to wrap a series of
 single-page managers."""
 
 import datatypes
-from reportlab.pdfgen.canvas import Canvas
+
+try:
+    from reportlab.pdfgen.canvas import Canvas
+except ImportError:
+    import warnings
+    warnings.warn(
+        "Reportlab not found - you will not be able to generate pdf documents.",
+        ImportWarning
+        )
 
 def render_to_reportlab_canvas(rl_canvas, papersize_tuple, manager):
     """Renders the given manager full size on a page of the given canvas."""
@@ -19,4 +27,3 @@ def render_to_reportlab_document(output_filename, papersize_tuple, manager):
     c = Canvas(output_filename, papersize_tuple)
     render_to_reportlab_canvas(c, papersize_tuple, manager)
     c.save()
-    
